#ifndef NT2_INCLUDE_FUNCTIONS_IMAG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IMAG_HPP_INCLUDED

#include <nt2/complex/include/functions/imag.hpp>

#endif
